summaryrefslogtreecommitdiff
path: root/test/reel_asset_test.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2024-06-28 19:27:50 +0200
committerCarl Hetherington <cth@carlh.net>2024-08-17 12:57:31 +0200
commitb64644327bff333569bf4a60f1d7c3d46f058b48 (patch)
treec7332cca06c2a171ce91c691760686d03882c919 /test/reel_asset_test.cc
parent32f8cc149c8c78c82f9f7e3689e43c11da362968 (diff)
Reel{,Interop,SMPTE}SubtitleAsset -> Reel{,Interop,SMPTE}TextAsset.
Diffstat (limited to 'test/reel_asset_test.cc')
-rw-r--r--test/reel_asset_test.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/reel_asset_test.cc b/test/reel_asset_test.cc
index 9dd2f8c3..f8974f63 100644
--- a/test/reel_asset_test.cc
+++ b/test/reel_asset_test.cc
@@ -33,7 +33,7 @@
#include "reel_mono_picture_asset.h"
-#include "reel_smpte_subtitle_asset.h"
+#include "reel_smpte_text_asset.h"
#include <libcxml/cxml.h>
#include <boost/test/unit_test.hpp>
#include "stream_operators.h"
@@ -78,7 +78,7 @@ BOOST_AUTO_TEST_CASE (reel_picture_asset_test)
}
/** Test the XML constructor of ReelSMPTESubtitleAsset */
BOOST_AUTO_TEST_CASE (reel_smpte_subtitle_asset_test)
{
auto doc = make_shared<cxml::Document>("MainSubtitle");
@@ -97,7 +97,7 @@ BOOST_AUTO_TEST_CASE (reel_smpte_subtitle_asset_test)
"</MainSubtitle>"
);
- dcp::ReelSMPTESubtitleAsset ps (doc);
+ dcp::ReelSMPTETextAsset ps (doc);
BOOST_CHECK_EQUAL (ps.id(), "8bca1489-aab1-9259-a4fd-8150abc1de12");
BOOST_CHECK_EQUAL (ps.annotation_text().get_value_or(""), "Goodbye world!");
BOOST_CHECK_EQUAL (ps.edit_rate(), dcp::Fraction(25, 1));
@@ -78,7 +78,7 @@ BOOST_AUTO_TEST_CASE (reel_picture_asset_test)
}
-/** Test the XML constructor of ReelSMPTESubtitleAsset */
+/** Test the XML constructor of ReelSMPTETextAsset */
BOOST_AUTO_TEST_CASE (reel_smpte_subtitle_asset_test)
{